# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/dish_config.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/dish_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spacex/api/device/dish_config.proto\x12\x11SpaceX.API.Device\"\xe9\x08\n\nDishConfig\x12P\n\x0esnow_melt_mode\x18\x01 \x01(\x0e\x32*.SpaceX.API.Device.DishConfig.SnowMeltModeR\x0csnowMeltMode\x12\x30\n\x14\x61pply_snow_melt_mode\x18\xe9\x07 \x01(\x08R\x11\x61pplySnowMeltMode\x12\x65\n\x15location_request_mode\x18\x02 \x01(\x0e\x32\x31.SpaceX.API.Device.DishConfig.LocationRequestModeR\x13locationRequestMode\x12>\n\x1b\x61pply_location_request_mode\x18\xd1\x0f \x01(\x08R\x18\x61pplyLocationRequestMode\x12S\n\x0flevel_dish_mode\x18\x03 \x01(\x0e\x32+.SpaceX.API.Device.DishConfig.LevelDishModeR\rlevelDishMode\x12\x32\n\x15\x61pply_level_dish_mode\x18\xb9\x17 \x01(\x08R\x12\x61pplyLevelDishMode\x12\x37\n\x18power_save_start_minutes\x18\x04 \x01(\rR\x15powerSaveStartMinutes\x12\x43\n\x1e\x61pply_power_save_start_minutes\x18\xa1\x1f \x01(\x08R\x1a\x61pplyPowerSaveStartMinutes\x12=\n\x1bpower_save_duration_minutes\x18\x05 \x01(\rR\x18powerSaveDurationMinutes\x12I\n!apply_power_save_duration_minutes\x18\x89\' \x01(\x08R\x1d\x61pplyPowerSaveDurationMinutes\x12&\n\x0fpower_save_mode\x18\x06 \x01(\x08R\rpowerSaveMode\x12\x32\n\x15\x61pply_power_save_mode\x18\xf1. \x01(\x08R\x12\x61pplyPowerSaveMode\x12L\n#swupdate_three_day_deferral_enabled\x18\x07 \x01(\x08R\x1fswupdateThreeDayDeferralEnabled\x12X\n)apply_swupdate_three_day_deferral_enabled\x18\xd9\x36 \x01(\x08R$applySwupdateThreeDayDeferralEnabled\"7\n\x0cSnowMeltMode\x12\x08\n\x04\x41UTO\x10\x00\x12\r\n\tALWAYS_ON\x10\x01\x12\x0e\n\nALWAYS_OFF\x10\x02\"*\n\x13LocationRequestMode\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\"6\n\rLevelDishMode\x12\x14\n\x10TILT_LIKE_NORMAL\x10\x00\x12\x0f\n\x0b\x46ORCE_LEVEL\x10\x01\x42\xd9\x01\n\x15\x63om.SpaceX.API.DeviceB\x0f\x44ishConfigProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.dish_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\017DishConfigProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_DISHCONFIG']._serialized_start=59
  _globals['_DISHCONFIG']._serialized_end=1188
  _globals['_DISHCONFIG_SNOWMELTMODE']._serialized_start=1033
  _globals['_DISHCONFIG_SNOWMELTMODE']._serialized_end=1088
  _globals['_DISHCONFIG_LOCATIONREQUESTMODE']._serialized_start=1090
  _globals['_DISHCONFIG_LOCATIONREQUESTMODE']._serialized_end=1132
  _globals['_DISHCONFIG_LEVELDISHMODE']._serialized_start=1134
  _globals['_DISHCONFIG_LEVELDISHMODE']._serialized_end=1188
# @@protoc_insertion_point(module_scope)
