# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/telemetron/public/common/time.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/telemetron/public/common/time.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spacex/api/telemetron/public/common/time.proto\x12#SpaceX.API.Telemetron.Public.Common\"s\n\rTimestampInfo\x12@\n\x05\x65poch\x18\x01 \x01(\x0e\x32*.SpaceX.API.Telemetron.Public.Common.EpochR\x05\x65poch\x12 \n\x0bnanoseconds\x18\x02 \x01(\x03R\x0bnanoseconds*\x1a\n\x05\x45poch\x12\x08\n\x04UNIX\x10\x00\x12\x07\n\x03GPS\x10\x01\x42\xc5\x02\n\'com.SpaceX.API.Telemetron.Public.CommonB\tTimeProtoP\x01Z[github.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/telemetron/public/common\xa2\x02\x05SATPC\xaa\x02#SpaceX.API.Telemetron.Public.Common\xca\x02$SpaceX\\API\\Telemetron\\Public_\\Common\xe2\x02\x30SpaceX\\API\\Telemetron\\Public_\\Common\\GPBMetadata\xea\x02\'SpaceX::API::Telemetron::Public::Commonb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.telemetron.public.common.time_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.SpaceX.API.Telemetron.Public.CommonB\tTimeProtoP\001Z[github.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/telemetron/public/common\242\002\005SATPC\252\002#SpaceX.API.Telemetron.Public.Common\312\002$SpaceX\\API\\Telemetron\\Public_\\Common\342\0020SpaceX\\API\\Telemetron\\Public_\\Common\\GPBMetadata\352\002\'SpaceX::API::Telemetron::Public::Common'
  _globals['_EPOCH']._serialized_start=204
  _globals['_EPOCH']._serialized_end=230
  _globals['_TIMESTAMPINFO']._serialized_start=87
  _globals['_TIMESTAMPINFO']._serialized_end=202
# @@protoc_insertion_point(module_scope)
