# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/satellites/network/ut_disablement_codes.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/satellites/network/ut_disablement_codes.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8spacex/api/satellites/network/ut_disablement_codes.proto\x12\x1dSpaceX.API.Satellites.Network*\xf0\x01\n\x11UtDisablementCode\x12\x11\n\rUNKNOWN_STATE\x10\x00\x12\x08\n\x04OKAY\x10\x01\x12\x15\n\x11NO_ACTIVE_ACCOUNT\x10\x02\x12 \n\x1cTOO_FAR_FROM_SERVICE_ADDRESS\x10\x03\x12\x0c\n\x08IN_OCEAN\x10\x04\x12\x13\n\x0fINVALID_COUNTRY\x10\x05\x12\x13\n\x0f\x42LOCKED_COUNTRY\x10\x06\x12\x1f\n\x1b\x44\x41TA_OVERAGE_SANDBOX_POLICY\x10\x07\x12\x14\n\x10\x43\x45LL_IS_DISABLED\x10\x08\x12\x16\n\x12UNLICENSED_COUNTRY\x10\tB\xab\x02\n!com.SpaceX.API.Satellites.NetworkB\x17UtDisablementCodesProtoP\x01ZUgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/satellites/network\xa2\x02\x04SASN\xaa\x02\x1dSpaceX.API.Satellites.Network\xca\x02\x1dSpaceX\\API\\Satellites\\Network\xe2\x02)SpaceX\\API\\Satellites\\Network\\GPBMetadata\xea\x02 SpaceX::API::Satellites::Networkb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.satellites.network.ut_disablement_codes_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.SpaceX.API.Satellites.NetworkB\027UtDisablementCodesProtoP\001ZUgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/satellites/network\242\002\004SASN\252\002\035SpaceX.API.Satellites.Network\312\002\035SpaceX\\API\\Satellites\\Network\342\002)SpaceX\\API\\Satellites\\Network\\GPBMetadata\352\002 SpaceX::API::Satellites::Network'
  _globals['_UTDISABLEMENTCODE']._serialized_start=92
  _globals['_UTDISABLEMENTCODE']._serialized_end=332
# @@protoc_insertion_point(module_scope)
