# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/rssi_scan.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/rssi_scan.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!spacex/api/device/rssi_scan.proto\x12\x11SpaceX.API.Device\"\x94\x01\n\tRssiEntry\x12!\n\x0ctheta_degree\x18\x01 \x01(\x01R\x0bthetaDegree\x12\x1d\n\nphi_degree\x18\x02 \x01(\x01R\tphiDegree\x12\x19\n\x08rssi_dbf\x18\x03 \x01(\x01R\x07rssiDbf\x12*\n\x11scan_timestamp_ms\x18\x04 \x01(\x04R\x0fscanTimestampMs\"0\n\x14\x44ishActivateRssiScan\x12\x18\n\x07\x63hannel\x18\x01 \x01(\rR\x07\x63hannel\"\xe7\x01\n\x15\x44ishGetRssiScanResult\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x18\n\x07\x63hannel\x18\x02 \x01(\rR\x07\x63hannel\x12+\n\x11request_timestamp\x18\x03 \x01(\x04R\x10requestTimestamp\x12%\n\x0enumber_samples\x18\x04 \x01(\rR\rnumberSamples\x12\x46\n\x10rssi_scan_points\x18\x05 \x03(\x0b\x32\x1c.SpaceX.API.Device.RssiEntryR\x0erssiScanPointsB\xd7\x01\n\x15\x63om.SpaceX.API.DeviceB\rRssiScanProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.rssi_scan_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\rRssiScanProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_RSSIENTRY']._serialized_start=57
  _globals['_RSSIENTRY']._serialized_end=205
  _globals['_DISHACTIVATERSSISCAN']._serialized_start=207
  _globals['_DISHACTIVATERSSISCAN']._serialized_end=255
  _globals['_DISHGETRSSISCANRESULT']._serialized_start=258
  _globals['_DISHGETRSSISCANRESULT']._serialized_end=489
# @@protoc_insertion_point(module_scope)
