# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/common/status/status.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/common/status/status.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%spacex/api/common/status/status.proto\x12\x11SpaceX.API.Status\"6\n\x06Status\x12\x12\n\x04\x63ode\x18\x01 \x01(\x05R\x04\x63ode\x12\x18\n\x07message\x18\x02 \x01(\tR\x07messageB\xdc\x01\n\x15\x63om.SpaceX.API.StatusB\x0bStatusProtoP\x01ZPgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/common/status\xa2\x02\x03SAS\xaa\x02\x11SpaceX.API.Status\xca\x02\x11SpaceX\\API\\Status\xe2\x02\x1dSpaceX\\API\\Status\\GPBMetadata\xea\x02\x13SpaceX::API::Statusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.common.status.status_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.StatusB\013StatusProtoP\001ZPgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/common/status\242\002\003SAS\252\002\021SpaceX.API.Status\312\002\021SpaceX\\API\\Status\342\002\035SpaceX\\API\\Status\\GPBMetadata\352\002\023SpaceX::API::Status'
  _globals['_STATUS']._serialized_start=60
  _globals['_STATUS']._serialized_end=114
# @@protoc_insertion_point(module_scope)
